@@ -1,14 +1,10 @@
 /* ============================================================
- *
- * This file is part of the KDE project
- *
- * Date        : 2007-09-13
- * Description : Sane interface for KDE
  *
  * SPDX-FileCopyrightText: 2007-2010 Kare Sars <kare dot sars at iki dot fi>
  * SPDX-FileCopyrightText: 2007 Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
- *
+ * SPDX-FileCopyrightText: 2021 Alexander Stippich <a.stippich@gmx.net>
+ * 
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  * ============================================================ */
@@ -25,7 +21,7 @@ namespace KSaneIface
 {
 
 class KSaneWidgetPrivate;
-
+    
 /**
  * This class provides the widget containing the scan options and the preview.
  * @author Kare Sars <kare.sars@iki.fi>
@@ -74,7 +70,7 @@ public:
     KSaneWidget(QWidget *parent = nullptr);
 
     /** Standard destructor */
-    ~KSaneWidget();
+    ~KSaneWidget() override;
 
     /** This helper method displays a dialog for selecting a scanner. The libsane
      * device name of the selected scanner device is returned. */
@@ -102,8 +98,9 @@ public:
      * This is a convenience method that can be used to create a QImage from the image data
      * returned by the imageReady(...) signal.
      * @note: If the image data has 16 bits/color the * data is truncated to 8 bits/color
-     * since QImage does not support 16 bits/color. A warning message will be shown.
-     *
+     * A warning message will be shown.
+     * @deprecated since 21.08
+     * @see use scannedImageReady(const QImage &scannedImage) and directly use the provided QImage
      * @param data is the byte data containing the image.
      * @param width is the width of the image in pixels.
      * @param height is the height of the image in pixels.
@@ -111,7 +108,7 @@ public:
      * and is probably only relevant for 'FormatBlackWhite'.
      * @param format is the KSane image format of the data.
      * @return This function returns the provided image data as a QImage. */
-    QImage toQImage(const QByteArray &data,
+    KSANE_DEPRECATED QImage toQImage(const QByteArray &data,
                     int width,
                     int height,
                     int bytes_per_line,
@@ -122,7 +119,8 @@ public:
      * returned by the imageReady(...) signal.
      * @note: If the image data has 16 bits/color the * data is truncated to 8 bits/color, but
      * unlike toQImage() this function will not give a warning.
-     *
+     * @deprecated since 21.08
+     * @see use scannedImageReady(const QImage &scannedImage) and directly use the provided QImage
      * @param data is the byte data containing the image.
      * @param width is the width of the image in pixels.
      * @param height is the height of the image in pixels.
@@ -130,7 +128,7 @@ public:
      * and is probably only relevant for 'FormatBlackWhite'.
      * @param format is the KSane image format of the data.
      * @return This function returns the provided image data as a QImage. */
-    QImage toQImageSilent(const QByteArray &data,
+    KSANE_DEPRECATED QImage toQImageSilent(const QByteArray &data,
                           int width,
                           int height,
                           int bytes_per_line,
@@ -139,7 +137,8 @@ public:
     /**
      * This is a static version of toQImageSilent() method that requires dpi as additional
      * argument. Non-static version uses currentDPI() for it.
-     *
+     * @deprecated since 21.08
+     * @see use scannedImageReady(const QImage &scannedImage) and directly use the provided QImage
      * @param data is the byte data containing the image.
      * @param width is the width of the image in pixels.
      * @param height is the height of the image in pixels.
@@ -148,7 +147,7 @@ public:
      * @param format is the KSane image format of the data.
      * @param dpi is the dpi value of the image.
      * @return This function returns the provided image data as a QImage. */
-    static
+    KSANE_DEPRECATED static
     QImage toQImageSilent(const QByteArray &data,
                           int width,
                           int height,
@@ -201,7 +200,7 @@ public:
     * @note if the set value is not supported, the cloasest one is used
     * @note setting the value 0 means that the default calculated value should be used */
     void setPreviewResolution(float dpi);
-
+    
     /** This method reads the available parameters and their values and
      * returns them in a QMap (Name, value)
      * @param opts is a QMap with the parameter names and values. */
@@ -261,15 +260,22 @@ public Q_SLOTS:
     void startPreviewScan();
 
 Q_SIGNALS:
+    /**
+     * This signal is emitted when a final scan is ready.
+     * @param scannedImage is the QImage containing the scanned image data. */
+    void scannedImageReady(const QImage &scannedImage);
+
     /**
      * This Signal is emitted when a final scan is ready.
+     * @deprecated since 21.08
+     * @see use new scannedImageReady(const QImage &scannedImage) instead
      * @param data is the byte data containing the image.
      * @param width is the width of the image in pixels.
      * @param height is the height of the image in pixels.
      * @param bytes_per_line is the number of bytes used per line. This might include padding
      * and is probably only relevant for 'FormatBlackWhite'.
      * @param format is the KSane image format of the data. */
-    void imageReady(QByteArray &data, int width, int height,
+    KSANE_DEPRECATED void imageReady(QByteArray &data, int width, int height,
                     int bytes_per_line, int format);
 
     /**
@@ -317,8 +323,7 @@ Q_SIGNALS:
     void buttonPressed(const QString &optionName, const QString &optionLabel, bool pressed);
     
     /**
-     * This Signal is emitted when the device info of the already opened scanner device
-     * is updated and vendor() and model() return the corresponding names.
+     * This signal is not emitted anymore.
      */
     void openedDeviceInfoUpdated(const QString &deviceName, const QString &deivceVendor, const QString &deviceModel);
 
